@@ -5,8 +5,8 @@ TAR=../javamail_$VERSION.orig.tar.xz
 DIR=javamail-$VERSION
 
 mkdir -p $DIR
-unzip ../$3 -d $DIR
-rm ../$3
+unzip $3 -d $DIR
+rm $3
 XZ_OPT=--best tar -c -J -f $TAR $DIR
 rm -rf $DIR
 
